Changelog
=========


1.0a3 (2019-08-23)
------------------

- Pep8, isort and code-analysis fixes. [Andreas Mantke]



1.0b1 (2019-08-23)
------------------

- Add notifications module [Andreas Mantke]
- Fix css-class names in addonrelease and addonlinkedrelease
  view [Andreas Mantke]
- Move a css inline style to the style sheet file [Andreas Mantke]
- Pep8 fixes [Andreas Mantke]
- Update localization template file and localization files,
  update German translation. [Andreas Mantke



1.0a2 (2019-08-16)
------------------

- Fix regular expressions for file extension validation [Andreas Mantke]
- Add import for Invalid to the addoncenter module [Andreas Mantke]
- Add necessary imports for virus scanning with
  collective.clamaav [Andreas Mantke]
- Fix title strings and field namings [Andreas Mantke]
- Update localization template file and localization files and
  add the missing German localization strings [Andreas Mantke]



1.0a1 (2019-08-13)
------------------

- Initial release.
  [andreasma]
